.. currentmodule:: clouddrift

API
===

Auto-generated summary of CloudDrift's API. For more details and examples, refer to the different Jupyter Notebooks.

Adapters
--------

.. automodule:: clouddrift.adapters
  :members:
  :undoc-members:

GDP (hourly)
^^^^^^^^^^^^

.. automodule:: clouddrift.adapters.gdp1h
  :members:
  :undoc-members:

GDP (6-hourly)
^^^^^^^^^^^^^^

.. automodule:: clouddrift.adapters.gdp6h
  :members:
  :undoc-members:

Analysis
--------

.. automodule:: clouddrift.analysis
  :members:
  :undoc-members:

Datasets
--------

.. automodule:: clouddrift.datasets
  :members:
  :undoc-members:

RaggedArray
-----------

.. automodule:: clouddrift.raggedarray
  :members:
  :undoc-members:

Sphere
---------

.. automodule:: clouddrift.sphere
  :members:
  :undoc-members:
